==> casper_2.0.2.tar.gz: casper/R/GenericDefs.R <==
setGeneric("genePlot", function(generanges, islandid, genomeDB, reads, exp, names.arg, xlab='', ylab='', xlim, cex=1, yaxt='n', col, ...) standardGeneric("genePlot"))
setGeneric("getIsland", function(entrezid, txid, genomeDB) standardGeneric("getIsland"))
setGeneric("getChr", function(entrezid, txid, islandid, genomeDB) standardGeneric("getChr"))
setGeneric("getNreads", function(pc) standardGeneric("getNreads"))
setGeneric("getReads", function(x) standardGeneric("getReads"))
setGeneric("getRoc", function(simTruth, decision) standardGeneric("getRoc"))
setGeneric("mergeBatches", function(x,y,mc.cores=1) standardGeneric("mergeBatches"))
setGeneric("plotExpr", function(gene, minProbExpr=.5, minExpr=.1, xlab='(kb)', ylab='', xlim, cex=1, yaxt='n', col, ...) standardGeneric("plotExpr"))
setGeneric("procBam", function(bam, stranded, seed, verbose=FALSE, rname, keep.junx=FALSE, keep.flag=FALSE, ...) standardGeneric("procBam"))
setGeneric("procGenome", function(genDB, genome, mc.cores=1) standardGeneric("procGenome"))
setGeneric("probNonEquiv", function(x, groups, logfc=log(2), minCount, method="plugin", mc.cores=1) standardGeneric("probNonEquiv"))
setGeneric("pvalTreat", function(x, groups, logfc=log(2), minCount, p.adjust.method='none', mc.cores=1) standardGeneric("pvalTreat"))
setGeneric("qqnormGenomeWide", function(x, ngenes=min(1000,nrow(x)), ...) standardGeneric("qqnormGenomeWide"))
setGeneric("quantileNorm", function(x) standardGeneric("quantileNorm"))
setGeneric("rangesPlot",function(x, gene, exonProfile=TRUE, maxFragLength=500, xlab='', ylab='', xlim, ...) standardGeneric("rangesPlot"))
setGeneric("transcripts", function(entrezid, islandid, genomeDB) standardGeneric("transcripts"))
setGeneric("variants", function(object) standardGeneric("variants"))

==> casper_2.28.0.tar.gz: casper/R/GenericDefs.R <==
setGeneric("genePlot", function(generanges, islandid, genomeDB, reads, exp, names.arg, xlab='', ylab='', xlim, cex=1, yaxt='n', col, ...) standardGeneric("genePlot"))
setGeneric("getIsland", function(entrezid, txid, genomeDB) standardGeneric("getIsland"))
setGeneric("getChr", function(entrezid, txid, islandid, genomeDB) standardGeneric("getChr"))
setGeneric("getNreads", function(pc) standardGeneric("getNreads"))
setGeneric("getReads", function(x) standardGeneric("getReads"))
setGeneric("getRoc", function(simTruth, decision) standardGeneric("getRoc"))
setGeneric("mergeBatches", function(x,y,mc.cores=1) standardGeneric("mergeBatches"))
setGeneric("plotExpr", function(gene, minProbExpr=.5, minExpr=.1, xlab='(kb)', ylab='', xlim, cex=1, yaxt='n', col, ...) standardGeneric("plotExpr"))
setGeneric("procBam", function(bam, stranded=FALSE, seed=as.integer(1), verbose=FALSE, rname='null', keep.junx=FALSE, keep.flag=FALSE, ispaired=TRUE,...) standardGeneric("procBam"))
setGeneric("procGenome", function(genDB, genome, mc.cores=1, verbose=TRUE) standardGeneric("procGenome"))
setGeneric("probNonEquiv", function(x, groups, logfc=log(2), minCount, method="plugin", mc.cores=1) standardGeneric("probNonEquiv"))
setGeneric("pvalTreat", function(x, groups, logfc=log(2), minCount, p.adjust.method='none', mc.cores=1) standardGeneric("pvalTreat"))
setGeneric("qqgammaGenomeWide", function(x, ngenes=min(1000,nrow(x)), ...) standardGeneric("qqgammaGenomeWide"))
setGeneric("qqnormGenomeWide", function(x, ngenes=min(1000,nrow(x)), ...) standardGeneric("qqnormGenomeWide"))
setGeneric("quantileNorm", function(x) standardGeneric("quantileNorm"))
setGeneric("rangesPlot",function(x, gene, exonProfile=TRUE, maxFragLength=500, xlab='', ylab='', xlim, ...) standardGeneric("rangesPlot"))
setGeneric("transcripts", function(genomeDB, txid, islandid) standardGeneric("transcripts"))
setGeneric("variants", function(object) standardGeneric("variants"))
setGeneric("procExp", function(distrs, genomeDB, pc, readLength, islandid, rpkm=TRUE, priorq=2, priorqGeneExpr=2, citype='none', niter=10^3, burnin=100, mc.cores=1, verbose=FALSE, totReads, tgroups=5, min.gt.freq=NULL) standardGeneric("procExp"))
